<?php

namespace Drupal\assertion;

use Drupal\assertion\Entity\AssertionInterface;
use Drupal\Core\Entity\Sql\SqlContentEntityStorage;
use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the storage handler class for Assertion entities.
 *
 * This extends the base storage class, adding required special handling for
 * Assertion entities.
 *
 * @ingroup assertion
 */
class AssertionStorage extends SqlContentEntityStorage implements AssertionStorageInterface {

  /**
   * {@inheritdoc}
   */
  public function revisionIds(AssertionInterface $entity) {
    return $this->database->query(
      'SELECT vid FROM {assertion_revision} WHERE id=:id ORDER BY vid',
      [':id' => $entity->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function userRevisionIds(AccountInterface $account) {
    return $this->database->query(
      'SELECT vid FROM {assertion_field_revision} WHERE uid = :uid ORDER BY vid',
      [':uid' => $account->id()]
    )->fetchCol();
  }

  /**
   * {@inheritdoc}
   */
  public function countDefaultLanguageRevisions(AssertionInterface $entity) {
    return $this->database->query('SELECT COUNT(*) FROM {assertion_field_revision} WHERE id = :id AND default_langcode = 1', [':id' => $entity->id()])
      ->fetchField();
  }

  /**
   * {@inheritdoc}
   */
  public function clearRevisionsLanguage(LanguageInterface $language) {
    return $this->database->update('assertion_revision')
      ->fields(['langcode' => LanguageInterface::LANGCODE_NOT_SPECIFIED])
      ->condition('langcode', $language->getId())
      ->execute();
  }

}
